@@ -23,10 +23,10 @@ int32_t SPVM__Sys__IO__FileStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(fh);
 
-  int32_t no_need_free = env->get_field_byte_by_name(env, stack, obj_self, "no_need_free", &error_id, __func__, FILE_NAME, __LINE__);
+  int32_t no_close = env->get_field_byte_by_name(env, stack, obj_self, "no_close", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  if (!no_need_free) {
+  if (!no_close) {
     if (!closed) {
       int32_t status = fclose(fh);
       if (status == EOF) {
