@@ -23,10 +23,12 @@ int32_t SPVM__Sys__Poll__PollfdArray__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t length = stack[0].ival;
   
   if (!(length >= 0)) {
-    return env->die(env, stack, "The length must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
-  struct pollfd* fds = env->new_memory_block(env, stack, sizeof(struct pollfd) * length);
+  int32_t alloc_length = length == 0 ? sizeof(struct pollfd) * 1 : sizeof(struct pollfd) * length;
+  
+  struct pollfd* fds = env->new_memory_block(env, stack, alloc_length);
   
   int32_t fields_length = 1;
   void* obj_self = env->new_pointer_object_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &error_id, __func__, FILE_NAME, __LINE__);
